@@ -10,7 +10,12 @@ import publication
 
 import aws_cdk.core._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-synthetics", "1.45.0", __name__[0:-6], "aws-synthetics@1.45.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-synthetics",
+    "1.52.0",
+    __name__[0:-6],
+    "aws-synthetics@1.52.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
